// python wrapper for vtkBoostBreadthFirstSearchTree
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkStdString.h"
#include "vtkBoostBreadthFirstSearchTree.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkBoostBreadthFirstSearchTree(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkBoostBreadthFirstSearchTree_ClassNew(); }

#ifndef DECLARED_PyvtkTreeAlgorithm_ClassNew
extern "C" { PyObject *PyvtkTreeAlgorithm_ClassNew(); }
#define DECLARED_PyvtkTreeAlgorithm_ClassNew
#endif

static const char *PyvtkBoostBreadthFirstSearchTree_Doc =
  "vtkBoostBreadthFirstSearchTree - Constructs a BFS tree from a graph\n\n"
  "Superclass: vtkTreeAlgorithm\n\n"
  "This vtk class uses the Boost breadth_first_search generic algorithm\n"
  "to perform a breadth first search from a given a 'source' vertex on\n"
  "the input graph (a vtkGraph). The result is a tree with root node\n"
  "corresponding to the start node of the search.\n\n"
  "@sa\n"
  "vtkGraph vtkBoostGraphAdapter\n\n";


static PyObject *
PyvtkBoostBreadthFirstSearchTree_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkBoostBreadthFirstSearchTree::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkBoostBreadthFirstSearchTree::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkBoostBreadthFirstSearchTree *tempr = vtkBoostBreadthFirstSearchTree::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkBoostBreadthFirstSearchTree *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkBoostBreadthFirstSearchTree::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_SetOriginVertex_s1(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOriginVertex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  vtkIdType temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetOriginVertex(temp0);
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::SetOriginVertex(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyObject *
PyvtkBoostBreadthFirstSearchTree_SetOriginVertex_s2(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetOriginVertex");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  vtkStdString temp0;
  vtkVariant *temp1 = nullptr;
  PyObject *pobj1 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(2) &&
      ap.GetValue(temp0) &&
      ap.GetSpecialObject(temp1, pobj1, "vtkVariant"))
  {
    if (ap.IsBound())
    {
      op->SetOriginVertex(temp0, *temp1);
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::SetOriginVertex(temp0, *temp1);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  Py_XDECREF(pobj1);

  return result;
}

static PyObject *
PyvtkBoostBreadthFirstSearchTree_SetOriginVertex(PyObject *self, PyObject *args)
{
  int nargs = vtkPythonArgs::GetArgCount(self, args);

  switch(nargs)
  {
    case 1:
      return PyvtkBoostBreadthFirstSearchTree_SetOriginVertex_s1(self, args);
    case 2:
      return PyvtkBoostBreadthFirstSearchTree_SetOriginVertex_s2(self, args);
  }

  vtkPythonArgs::ArgCountError(nargs, "SetOriginVertex");
  return nullptr;
}



static PyObject *
PyvtkBoostBreadthFirstSearchTree_SetCreateGraphVertexIdArray(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetCreateGraphVertexIdArray");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetCreateGraphVertexIdArray(temp0);
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::SetCreateGraphVertexIdArray(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_GetCreateGraphVertexIdArray(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetCreateGraphVertexIdArray");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetCreateGraphVertexIdArray() :
      op->vtkBoostBreadthFirstSearchTree::GetCreateGraphVertexIdArray());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_CreateGraphVertexIdArrayOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateGraphVertexIdArrayOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->CreateGraphVertexIdArrayOn();
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::CreateGraphVertexIdArrayOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_CreateGraphVertexIdArrayOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "CreateGraphVertexIdArrayOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->CreateGraphVertexIdArrayOff();
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::CreateGraphVertexIdArrayOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_SetReverseEdges(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetReverseEdges");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetReverseEdges(temp0);
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::SetReverseEdges(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_GetReverseEdges(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetReverseEdges");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetReverseEdges() :
      op->vtkBoostBreadthFirstSearchTree::GetReverseEdges());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_ReverseEdgesOn(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReverseEdgesOn");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReverseEdgesOn();
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::ReverseEdgesOn();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkBoostBreadthFirstSearchTree_ReverseEdgesOff(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "ReverseEdgesOff");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkBoostBreadthFirstSearchTree *op = static_cast<vtkBoostBreadthFirstSearchTree *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    if (ap.IsBound())
    {
      op->ReverseEdgesOff();
    }
    else
    {
      op->vtkBoostBreadthFirstSearchTree::ReverseEdgesOff();
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}

static PyMethodDef PyvtkBoostBreadthFirstSearchTree_Methods[] = {
  {"IsTypeOf", PyvtkBoostBreadthFirstSearchTree_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkBoostBreadthFirstSearchTree_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkBoostBreadthFirstSearchTree_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkBoostBreadthFirstSearchTree\nC++: static vtkBoostBreadthFirstSearchTree *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkBoostBreadthFirstSearchTree_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkBoostBreadthFirstSearchTree\nC++: vtkBoostBreadthFirstSearchTree *NewInstance()\n\n"},
  {"SetOriginVertex", PyvtkBoostBreadthFirstSearchTree_SetOriginVertex, METH_VARARGS,
   "V.SetOriginVertex(int)\nC++: void SetOriginVertex(vtkIdType index)\nV.SetOriginVertex(string, vtkVariant)\nC++: void SetOriginVertex(vtkStdString arrayName,\n    vtkVariant value)\n\nSet the index (into the vertex array) of the breadth first search\n'origin' vertex.\n"},
  {"SetCreateGraphVertexIdArray", PyvtkBoostBreadthFirstSearchTree_SetCreateGraphVertexIdArray, METH_VARARGS,
   "V.SetCreateGraphVertexIdArray(bool)\nC++: virtual void SetCreateGraphVertexIdArray(bool _arg)\n\nStores the graph vertex ids for the tree vertices in an array\nnamed \"GraphVertexId\".  Default is off.\n"},
  {"GetCreateGraphVertexIdArray", PyvtkBoostBreadthFirstSearchTree_GetCreateGraphVertexIdArray, METH_VARARGS,
   "V.GetCreateGraphVertexIdArray() -> bool\nC++: virtual bool GetCreateGraphVertexIdArray()\n\nStores the graph vertex ids for the tree vertices in an array\nnamed \"GraphVertexId\".  Default is off.\n"},
  {"CreateGraphVertexIdArrayOn", PyvtkBoostBreadthFirstSearchTree_CreateGraphVertexIdArrayOn, METH_VARARGS,
   "V.CreateGraphVertexIdArrayOn()\nC++: virtual void CreateGraphVertexIdArrayOn()\n\nStores the graph vertex ids for the tree vertices in an array\nnamed \"GraphVertexId\".  Default is off.\n"},
  {"CreateGraphVertexIdArrayOff", PyvtkBoostBreadthFirstSearchTree_CreateGraphVertexIdArrayOff, METH_VARARGS,
   "V.CreateGraphVertexIdArrayOff()\nC++: virtual void CreateGraphVertexIdArrayOff()\n\nStores the graph vertex ids for the tree vertices in an array\nnamed \"GraphVertexId\".  Default is off.\n"},
  {"SetReverseEdges", PyvtkBoostBreadthFirstSearchTree_SetReverseEdges, METH_VARARGS,
   "V.SetReverseEdges(bool)\nC++: virtual void SetReverseEdges(bool _arg)\n\nTurn on this option to reverse the edges in the graph.\n"},
  {"GetReverseEdges", PyvtkBoostBreadthFirstSearchTree_GetReverseEdges, METH_VARARGS,
   "V.GetReverseEdges() -> bool\nC++: virtual bool GetReverseEdges()\n\nTurn on this option to reverse the edges in the graph.\n"},
  {"ReverseEdgesOn", PyvtkBoostBreadthFirstSearchTree_ReverseEdgesOn, METH_VARARGS,
   "V.ReverseEdgesOn()\nC++: virtual void ReverseEdgesOn()\n\nTurn on this option to reverse the edges in the graph.\n"},
  {"ReverseEdgesOff", PyvtkBoostBreadthFirstSearchTree_ReverseEdgesOff, METH_VARARGS,
   "V.ReverseEdgesOff()\nC++: virtual void ReverseEdgesOff()\n\nTurn on this option to reverse the edges in the graph.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkBoostBreadthFirstSearchTree_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkInfovisBoostGraphAlgorithmsPython.vtkBoostBreadthFirstSearchTree", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkBoostBreadthFirstSearchTree_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkBoostBreadthFirstSearchTree_StaticNew()
{
  return vtkBoostBreadthFirstSearchTree::New();
}

PyObject *PyvtkBoostBreadthFirstSearchTree_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkBoostBreadthFirstSearchTree_Type, PyvtkBoostBreadthFirstSearchTree_Methods,
    "vtkBoostBreadthFirstSearchTree",
 &PyvtkBoostBreadthFirstSearchTree_StaticNew);

  PyTypeObject *pytype = &PyvtkBoostBreadthFirstSearchTree_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkTreeAlgorithm_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkBoostBreadthFirstSearchTree(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkBoostBreadthFirstSearchTree_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkBoostBreadthFirstSearchTree", o) != 0)
  {
    Py_DECREF(o);
  }

}

