// python wrapper for vtkReebGraphToJoinSplitTreeFilter
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkReebGraphToJoinSplitTreeFilter.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkReebGraphToJoinSplitTreeFilter(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkReebGraphToJoinSplitTreeFilter_ClassNew(); }

#ifndef DECLARED_PyvtkDirectedGraphAlgorithm_ClassNew
extern "C" { PyObject *PyvtkDirectedGraphAlgorithm_ClassNew(); }
#define DECLARED_PyvtkDirectedGraphAlgorithm_ClassNew
#endif

static const char *PyvtkReebGraphToJoinSplitTreeFilter_Doc =
  "vtkReebGraphToJoinSplitTreeFilter - converts a given Reeb graph\neither to a join tree or a split tree (respectively the connectivity\nof the sub- and sur- level sets).\n\n"
  "Superclass: vtkDirectedGraphAlgorithm\n\n"
  "Note: if you want to use simplification filters, do so on the input\n"
  "Reeb graph first.\n\n"
  "Reference: \"Computing contpour trees in all dimensions\". H. Carr, J.\n"
  "Snoeyink, U. Axen. SODA 2000, pp. 918-926.\n\n"
  "The filter takes as an input the underlying mesh (port 0, a\n"
  "vtkPolyData for 2D meshes or a vtkUnstructuredGrid for 3D meshes)\n"
  "with an attached scalar field (identified by FieldId, with\n"
  "setFieldId()) and an input Reeb graph computed on that mesh (port 1).\n"
  "The outputs is vtkReebGraph object describing either a join or split\n"
  "tree.\n\n";


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkReebGraphToJoinSplitTreeFilter::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkReebGraphToJoinSplitTreeFilter::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkReebGraphToJoinSplitTreeFilter *tempr = vtkReebGraphToJoinSplitTreeFilter::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkReebGraphToJoinSplitTreeFilter *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkReebGraphToJoinSplitTreeFilter::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_SetIsSplitTree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetIsSplitTree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  bool temp0 = false;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetIsSplitTree(temp0);
    }
    else
    {
      op->vtkReebGraphToJoinSplitTreeFilter::SetIsSplitTree(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_GetIsSplitTree(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetIsSplitTree");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    bool tempr = (ap.IsBound() ?
      op->GetIsSplitTree() :
      op->vtkReebGraphToJoinSplitTreeFilter::GetIsSplitTree());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_SetFieldId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetFieldId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  vtkIdType temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetFieldId(temp0);
    }
    else
    {
      op->vtkReebGraphToJoinSplitTreeFilter::SetFieldId(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_GetFieldId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFieldId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkIdType tempr = (ap.IsBound() ?
      op->GetFieldId() :
      op->vtkReebGraphToJoinSplitTreeFilter::GetFieldId());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphToJoinSplitTreeFilter_GetOutput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetOutput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphToJoinSplitTreeFilter *op = static_cast<vtkReebGraphToJoinSplitTreeFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkReebGraph *tempr = (ap.IsBound() ?
      op->GetOutput() :
      op->vtkReebGraphToJoinSplitTreeFilter::GetOutput());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkReebGraphToJoinSplitTreeFilter_Methods[] = {
  {"IsTypeOf", PyvtkReebGraphToJoinSplitTreeFilter_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkReebGraphToJoinSplitTreeFilter_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkReebGraphToJoinSplitTreeFilter_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkReebGraphToJoinSplitTreeFilter\nC++: static vtkReebGraphToJoinSplitTreeFilter *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkReebGraphToJoinSplitTreeFilter_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkReebGraphToJoinSplitTreeFilter\nC++: vtkReebGraphToJoinSplitTreeFilter *NewInstance()\n\n"},
  {"SetIsSplitTree", PyvtkReebGraphToJoinSplitTreeFilter_SetIsSplitTree, METH_VARARGS,
   "V.SetIsSplitTree(bool)\nC++: virtual void SetIsSplitTree(bool _arg)\n\nSpecify if you want to get a join or a split tree. Default value:\nfalse (join tree)\n"},
  {"GetIsSplitTree", PyvtkReebGraphToJoinSplitTreeFilter_GetIsSplitTree, METH_VARARGS,
   "V.GetIsSplitTree() -> bool\nC++: virtual bool GetIsSplitTree()\n\nSpecify if you want to get a join or a split tree. Default value:\nfalse (join tree)\n"},
  {"SetFieldId", PyvtkReebGraphToJoinSplitTreeFilter_SetFieldId, METH_VARARGS,
   "V.SetFieldId(int)\nC++: virtual void SetFieldId(vtkIdType _arg)\n\nSet the scalar field Id Default value: 0;\n"},
  {"GetFieldId", PyvtkReebGraphToJoinSplitTreeFilter_GetFieldId, METH_VARARGS,
   "V.GetFieldId() -> int\nC++: virtual vtkIdType GetFieldId()\n\nSet the scalar field Id Default value: 0;\n"},
  {"GetOutput", PyvtkReebGraphToJoinSplitTreeFilter_GetOutput, METH_VARARGS,
   "V.GetOutput() -> vtkReebGraph\nC++: vtkReebGraph *GetOutput()\n\nGet the output data object for a port on this algorithm.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkReebGraphToJoinSplitTreeFilter_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkFiltersReebGraphPython.vtkReebGraphToJoinSplitTreeFilter", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkReebGraphToJoinSplitTreeFilter_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkReebGraphToJoinSplitTreeFilter_StaticNew()
{
  return vtkReebGraphToJoinSplitTreeFilter::New();
}

PyObject *PyvtkReebGraphToJoinSplitTreeFilter_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkReebGraphToJoinSplitTreeFilter_Type, PyvtkReebGraphToJoinSplitTreeFilter_Methods,
    "vtkReebGraphToJoinSplitTreeFilter",
 &PyvtkReebGraphToJoinSplitTreeFilter_StaticNew);

  PyTypeObject *pytype = &PyvtkReebGraphToJoinSplitTreeFilter_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkDirectedGraphAlgorithm_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkReebGraphToJoinSplitTreeFilter(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkReebGraphToJoinSplitTreeFilter_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkReebGraphToJoinSplitTreeFilter", o) != 0)
  {
    Py_DECREF(o);
  }

}

