// python wrapper for vtkReebGraphVolumeSkeletonFilter
//
#define VTK_WRAPPING_CXX
#define VTK_STREAMS_FWD_ONLY
#include "vtkPythonArgs.h"
#include "vtkPythonOverload.h"
#include "vtkConfigure.h"
#include <cstddef>
#include <sstream>
#include "vtkVariant.h"
#include "vtkIndent.h"
#include "vtkReebGraphVolumeSkeletonFilter.h"

extern "C" { VTK_ABI_EXPORT void PyVTKAddFile_vtkReebGraphVolumeSkeletonFilter(PyObject *); }
extern "C" { VTK_ABI_EXPORT PyObject *PyvtkReebGraphVolumeSkeletonFilter_ClassNew(); }

#ifndef DECLARED_PyvtkDataObjectAlgorithm_ClassNew
extern "C" { PyObject *PyvtkDataObjectAlgorithm_ClassNew(); }
#define DECLARED_PyvtkDataObjectAlgorithm_ClassNew
#endif

static const char *PyvtkReebGraphVolumeSkeletonFilter_Doc =
  "vtkReebGraphVolumeSkeletonFilter - compute a skeletal embedding of the\n\n"
  "Superclass: vtkDataObjectAlgorithm\n\n"
  "Reeb graph of a scalar field defined on a tetrahedral mesh\n"
  "(vtkUnstructuredGrid).\n\n"
  "The filter takes a vtkUnstructuredGrid as an input (port 0), along\n"
  "with a vtkReebGraph (port 1). The filter samples each arc of the Reeb\n"
  "graph and embeds the samples on the barycenter of the corresponding\n"
  "field contour. The number of (evenly distributed) arc samples can be\n"
  "defined with SetNumberOfSamples() (default value: 10). The skeleton\n"
  "can be optionally smoothed with SetNumberOfSmoothingIterations()\n"
  "(default value: 10). The filter will first try to pull as a scalar\n"
  "field the vtkDataArray with Id 'FieldId' of the vtkPolyData, see\n"
  "SetFieldId() (default: 0). The filter will abort if this field does\n"
  "not exist.\n\n"
  "The filter outputs a vtkTable of points (double[3]). Each column\n"
  "contains the samples (sorted by function value) of the corresponding\n"
  "arc. The first and the last entry of the column corresponds to the\n"
  "critical nodes at the extremity of the arc (each column has\n"
  "NumberOfSamples + 2 entries).\n\n"
  "The skeleton can be rendered by linking the samples with geometrical\n"
  "primitives (for instance, spheres at critical nodes and cylinders\n"
  "between intermediary samples, see\n"
  "Graphics/Testing/Cxx/TestReebGraph.cxx).\n\n";


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_IsTypeOf(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "IsTypeOf");

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = vtkReebGraphVolumeSkeletonFilter::IsTypeOf(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_IsA(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "IsA");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  const char *temp0 = nullptr;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    int tempr = (ap.IsBound() ?
      op->IsA(temp0) :
      op->vtkReebGraphVolumeSkeletonFilter::IsA(temp0));

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_SafeDownCast(PyObject *, PyObject *args)
{
  vtkPythonArgs ap(args, "SafeDownCast");

  vtkObjectBase *temp0 = nullptr;
  PyObject *result = nullptr;

  if (ap.CheckArgCount(1) &&
      ap.GetVTKObject(temp0, "vtkObjectBase"))
  {
    vtkReebGraphVolumeSkeletonFilter *tempr = vtkReebGraphVolumeSkeletonFilter::SafeDownCast(temp0);

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_NewInstance(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "NewInstance");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkReebGraphVolumeSkeletonFilter *tempr = (ap.IsBound() ?
      op->NewInstance() :
      op->vtkReebGraphVolumeSkeletonFilter::NewInstance());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
      if (result && PyVTKObject_Check(result))
      {
        PyVTKObject_GetObject(result)->UnRegister(0);
        PyVTKObject_SetFlag(result, VTK_PYTHON_IGNORE_UNREGISTER, 1);
      }
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_SetNumberOfSamples(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNumberOfSamples");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetNumberOfSamples(temp0);
    }
    else
    {
      op->vtkReebGraphVolumeSkeletonFilter::SetNumberOfSamples(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_GetNumberOfSamples(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfSamples");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfSamples() :
      op->vtkReebGraphVolumeSkeletonFilter::GetNumberOfSamples());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_SetNumberOfSmoothingIterations(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetNumberOfSmoothingIterations");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  int temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetNumberOfSmoothingIterations(temp0);
    }
    else
    {
      op->vtkReebGraphVolumeSkeletonFilter::SetNumberOfSmoothingIterations(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_GetNumberOfSmoothingIterations(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetNumberOfSmoothingIterations");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    int tempr = (ap.IsBound() ?
      op->GetNumberOfSmoothingIterations() :
      op->vtkReebGraphVolumeSkeletonFilter::GetNumberOfSmoothingIterations());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_SetFieldId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "SetFieldId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  vtkIdType temp0;
  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(1) &&
      ap.GetValue(temp0))
  {
    if (ap.IsBound())
    {
      op->SetFieldId(temp0);
    }
    else
    {
      op->vtkReebGraphVolumeSkeletonFilter::SetFieldId(temp0);
    }

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildNone();
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_GetFieldId(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetFieldId");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkIdType tempr = (ap.IsBound() ?
      op->GetFieldId() :
      op->vtkReebGraphVolumeSkeletonFilter::GetFieldId());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildValue(tempr);
    }
  }

  return result;
}


static PyObject *
PyvtkReebGraphVolumeSkeletonFilter_GetOutput(PyObject *self, PyObject *args)
{
  vtkPythonArgs ap(self, args, "GetOutput");
  vtkObjectBase *vp = ap.GetSelfPointer(self, args);
  vtkReebGraphVolumeSkeletonFilter *op = static_cast<vtkReebGraphVolumeSkeletonFilter *>(vp);

  PyObject *result = nullptr;

  if (op && ap.CheckArgCount(0))
  {
    vtkTable *tempr = (ap.IsBound() ?
      op->GetOutput() :
      op->vtkReebGraphVolumeSkeletonFilter::GetOutput());

    if (!ap.ErrorOccurred())
    {
      result = ap.BuildVTKObject(tempr);
    }
  }

  return result;
}

static PyMethodDef PyvtkReebGraphVolumeSkeletonFilter_Methods[] = {
  {"IsTypeOf", PyvtkReebGraphVolumeSkeletonFilter_IsTypeOf, METH_VARARGS,
   "V.IsTypeOf(string) -> int\nC++: static vtkTypeBool IsTypeOf(const char *type)\n\nReturn 1 if this class type is the same type of (or a subclass\nof) the named class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"IsA", PyvtkReebGraphVolumeSkeletonFilter_IsA, METH_VARARGS,
   "V.IsA(string) -> int\nC++: vtkTypeBool IsA(const char *type) override;\n\nReturn 1 if this class is the same type of (or a subclass of) the\nnamed class. Returns 0 otherwise. This method works in\ncombination with vtkTypeMacro found in vtkSetGet.h.\n"},
  {"SafeDownCast", PyvtkReebGraphVolumeSkeletonFilter_SafeDownCast, METH_VARARGS,
   "V.SafeDownCast(vtkObjectBase) -> vtkReebGraphVolumeSkeletonFilter\nC++: static vtkReebGraphVolumeSkeletonFilter *SafeDownCast(\n    vtkObjectBase *o)\n\n"},
  {"NewInstance", PyvtkReebGraphVolumeSkeletonFilter_NewInstance, METH_VARARGS,
   "V.NewInstance() -> vtkReebGraphVolumeSkeletonFilter\nC++: vtkReebGraphVolumeSkeletonFilter *NewInstance()\n\n"},
  {"SetNumberOfSamples", PyvtkReebGraphVolumeSkeletonFilter_SetNumberOfSamples, METH_VARARGS,
   "V.SetNumberOfSamples(int)\nC++: virtual void SetNumberOfSamples(int _arg)\n\nSet the number of samples along each arc of the Reeb graph\nDefault value: 5\n"},
  {"GetNumberOfSamples", PyvtkReebGraphVolumeSkeletonFilter_GetNumberOfSamples, METH_VARARGS,
   "V.GetNumberOfSamples() -> int\nC++: virtual int GetNumberOfSamples()\n\nSet the number of samples along each arc of the Reeb graph\nDefault value: 5\n"},
  {"SetNumberOfSmoothingIterations", PyvtkReebGraphVolumeSkeletonFilter_SetNumberOfSmoothingIterations, METH_VARARGS,
   "V.SetNumberOfSmoothingIterations(int)\nC++: virtual void SetNumberOfSmoothingIterations(int _arg)\n\nSet the number of optional smoothing iterations Default value: 30\n"},
  {"GetNumberOfSmoothingIterations", PyvtkReebGraphVolumeSkeletonFilter_GetNumberOfSmoothingIterations, METH_VARARGS,
   "V.GetNumberOfSmoothingIterations() -> int\nC++: virtual int GetNumberOfSmoothingIterations()\n\nSet the number of optional smoothing iterations Default value: 30\n"},
  {"SetFieldId", PyvtkReebGraphVolumeSkeletonFilter_SetFieldId, METH_VARARGS,
   "V.SetFieldId(int)\nC++: virtual void SetFieldId(vtkIdType _arg)\n\nSet the scalar field Id Default value: 0\n"},
  {"GetFieldId", PyvtkReebGraphVolumeSkeletonFilter_GetFieldId, METH_VARARGS,
   "V.GetFieldId() -> int\nC++: virtual vtkIdType GetFieldId()\n\nSet the scalar field Id Default value: 0\n"},
  {"GetOutput", PyvtkReebGraphVolumeSkeletonFilter_GetOutput, METH_VARARGS,
   "V.GetOutput() -> vtkTable\nC++: vtkTable *GetOutput()\n\nGet the output data object for a port on this algorithm.\n"},
  {nullptr, nullptr, 0, nullptr}
};

static PyTypeObject PyvtkReebGraphVolumeSkeletonFilter_Type = {
  PyVarObject_HEAD_INIT(&PyType_Type, 0)
  "vtkFiltersReebGraphPython.vtkReebGraphVolumeSkeletonFilter", // tp_name
  sizeof(PyVTKObject), // tp_basicsize
  0, // tp_itemsize
  PyVTKObject_Delete, // tp_dealloc
  0, // tp_vectorcall_offset
  nullptr, // tp_getattr
  nullptr, // tp_setattr
  nullptr, // tp_compare
  PyVTKObject_Repr, // tp_repr
  nullptr, // tp_as_number
  nullptr, // tp_as_sequence
  nullptr, // tp_as_mapping
  nullptr, // tp_hash
  nullptr, // tp_call
  PyVTKObject_String, // tp_str
  PyObject_GenericGetAttr, // tp_getattro
  PyObject_GenericSetAttr, // tp_setattro
  &PyVTKObject_AsBuffer, // tp_as_buffer
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_BASETYPE, // tp_flags
  PyvtkReebGraphVolumeSkeletonFilter_Doc, // tp_doc
  PyVTKObject_Traverse, // tp_traverse
  nullptr, // tp_clear
  nullptr, // tp_richcompare
  offsetof(PyVTKObject, vtk_weakreflist), // tp_weaklistoffset
  nullptr, // tp_iter
  nullptr, // tp_iternext
  nullptr, // tp_methods
  nullptr, // tp_members
  PyVTKObject_GetSet, // tp_getset
  nullptr, // tp_base
  nullptr, // tp_dict
  nullptr, // tp_descr_get
  nullptr, // tp_descr_set
  offsetof(PyVTKObject, vtk_dict), // tp_dictoffset
  nullptr, // tp_init
  nullptr, // tp_alloc
  PyVTKObject_New, // tp_new
  PyObject_GC_Del, // tp_free
  nullptr, // tp_is_gc
  nullptr, // tp_bases
  nullptr, // tp_mro
  nullptr, // tp_cache
  nullptr, // tp_subclasses
  nullptr, // tp_weaklist
  VTK_WRAP_PYTHON_SUPPRESS_UNINITIALIZED
};

static vtkObjectBase *PyvtkReebGraphVolumeSkeletonFilter_StaticNew()
{
  return vtkReebGraphVolumeSkeletonFilter::New();
}

PyObject *PyvtkReebGraphVolumeSkeletonFilter_ClassNew()
{
  PyVTKClass_Add(
    &PyvtkReebGraphVolumeSkeletonFilter_Type, PyvtkReebGraphVolumeSkeletonFilter_Methods,
    "vtkReebGraphVolumeSkeletonFilter",
 &PyvtkReebGraphVolumeSkeletonFilter_StaticNew);

  PyTypeObject *pytype = &PyvtkReebGraphVolumeSkeletonFilter_Type;

  if ((pytype->tp_flags & Py_TPFLAGS_READY) != 0)
  {
    return (PyObject *)pytype;
  }

#if !defined(VTK_PY3K) && PY_VERSION_HEX >= 0x02060000
  pytype->tp_flags |= Py_TPFLAGS_HAVE_NEWBUFFER;
#endif

  pytype->tp_base = (PyTypeObject *)PyvtkDataObjectAlgorithm_ClassNew();

  PyType_Ready(pytype);
  return (PyObject *)pytype;
}

void PyVTKAddFile_vtkReebGraphVolumeSkeletonFilter(
  PyObject *dict)
{
  PyObject *o;
  o = PyvtkReebGraphVolumeSkeletonFilter_ClassNew();

  if (o && PyDict_SetItemString(dict, "vtkReebGraphVolumeSkeletonFilter", o) != 0)
  {
    Py_DECREF(o);
  }

}

